==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/mixer/adapter/statsd/MetricInfoFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.statsd;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class MetricInfoFluentImpl<A extends me.snowdrop.istio.mixer.adapter.statsd.MetricInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements me.snowdrop.istio.mixer.adapter.statsd.MetricInfoFluent<A>{

    private String nameTemplate;
    private me.snowdrop.istio.mixer.adapter.statsd.Type type;

    public MetricInfoFluentImpl(){
    }
    public MetricInfoFluentImpl(me.snowdrop.istio.mixer.adapter.statsd.MetricInfo instance){
            this.withNameTemplate(instance.getNameTemplate()); 
            this.withType(instance.getType()); 
    }

    public String getNameTemplate(){
            return this.nameTemplate;
    }

    public A withNameTemplate(String nameTemplate){
            this.nameTemplate=nameTemplate; return (A) this;
    }

    public Boolean hasNameTemplate(){
            return this.nameTemplate != null;
    }

    public me.snowdrop.istio.mixer.adapter.statsd.Type getType(){
            return this.type;
    }

    public A withType(me.snowdrop.istio.mixer.adapter.statsd.Type type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            MetricInfoFluentImpl that = (MetricInfoFluentImpl) o;
            if (nameTemplate != null ? !nameTemplate.equals(that.nameTemplate) :that.nameTemplate != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }




}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/mixer/adapter/statsd/MetricInfoFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.statsd;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class MetricInfoFluentImpl<A extends me.snowdrop.istio.mixer.adapter.statsd.MetricInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements me.snowdrop.istio.mixer.adapter.statsd.MetricInfoFluent<A>{

    private String nameTemplate;
    private me.snowdrop.istio.mixer.adapter.statsd.Type type;

    public MetricInfoFluentImpl(){
    }
    public MetricInfoFluentImpl(me.snowdrop.istio.mixer.adapter.statsd.MetricInfo instance){
            this.withNameTemplate(instance.getNameTemplate()); 
            this.withType(instance.getType()); 
    }

    public String getNameTemplate(){
            return this.nameTemplate;
    }

    public A withNameTemplate(String nameTemplate){
            this.nameTemplate=nameTemplate; return (A) this;
    }

    public Boolean hasNameTemplate(){
            return this.nameTemplate != null;
    }

    public A withNewNameTemplate(String arg1){
            return (A)withNameTemplate(new String(arg1));
    }

    public A withNewNameTemplate(StringBuilder arg1){
            return (A)withNameTemplate(new String(arg1));
    }

    public A withNewNameTemplate(StringBuffer arg1){
            return (A)withNameTemplate(new String(arg1));
    }

    public me.snowdrop.istio.mixer.adapter.statsd.Type getType(){
            return this.type;
    }

    public A withType(me.snowdrop.istio.mixer.adapter.statsd.Type type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            MetricInfoFluentImpl that = (MetricInfoFluentImpl) o;
            if (nameTemplate != null ? !nameTemplate.equals(that.nameTemplate) :that.nameTemplate != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }




}
